@@ -11,43 +11,27 @@ class Model:
         assert name is not None
 
         if isinstance(uid, str):
-            self._uid = uuid.UUID(uid)
+            self.uid = uuid.UUID(uid)
         elif isinstance(uid, uuid.UUID):
-            self._uid = uid
+            self.uid = uid
         else:
             raise ValueError('Unsupported type: ' + str(type(uid)))
 
-        self._language = language
-        self._name = name
-        self._description = description
-
-    @property
-    def uid(self) -> uuid.UUID:
-        return self._uid
-
-    @property
-    def language(self) -> Language:
-        return self._language
-
-    @property
-    def name(self) -> str:
-        return self._name
-
-    @property
-    def description(self) -> str:
-        return self._description
+        self.language = language
+        self.name = name
+        self.description = description
 
     def __str__(self):
-        return f'{str(self._uid)} {self._name} {str(self._language)}'
+        return f'{str(self.uid)} {self.name} {str(self.language)}'
 
     def __eq__(self, other):
         if not isinstance(other, Model):
             return NotImplemented
 
-        return self._uid == other._uid
+        return self.uid == other.uid
 
     def __hash__(self):
-        return hash(self._uid)
+        return hash(self.uid)
 
 
 class ModelType(Enum):
