@@ -1,4 +1,3 @@
-from vatis.asr_commons.domain.transcriber import DictSerializable
 from vatis.asr_commons.domain.transcriber import DataPacket
 from vatis.asr_commons.domain.transcriber import ByteDataPacket
 from vatis.asr_commons.domain.transcriber import TranscriptionPacket
@@ -9,8 +8,6 @@ from vatis.asr_commons.domain.transcriber import LogitsDataPacket
 from vatis.asr_commons.domain.transcriber import SpacedLogitsDataPacket
 
 __all__ = (
-    'DictSerializable',
-    'DictSerializable',
     'ByteDataPacket',
     'TranscriptionPacket',
     'Word',
