@@ -6,6 +6,9 @@ FRAME_END_TIME_HEADER: str = 'FrameEndTime'
 FINAL_FRAME_HEADER: str = 'FinalFrame'
 SILENCE_DETECTED_HEADER: str = 'SilenceDetected'
 PROCESSING_TIME_SECONDS_HEADER: str = 'ProcessingTimeSeconds'
+SPLIT_PACKET_HEADER: str = 'SplitPacket'
+FINAL_SPLIT_PACKET_HEADER: str = 'FinalSplitPacket'
+SPLIT_ID_HEADER: str = 'SplitId'
 
 #  request headers ####################################################################################################
 FRAME_LEN_HEADER = 'FrameLength'
