@@ -20,7 +20,8 @@ class TranscriptionRequest:
     def __init__(self, file_uid: str, file_path: Union[str, Path], model: Model, success_url: Optional[str] = None,
                  fail_url: Optional[str] = None, hotwords: Optional[Union[list, str]] = None,
                  hotwords_weight: Optional[float] = None,
-                 transcript_format: TranscriptionResponseFormat = TranscriptionResponseFormat.JSON):
+                 transcript_format: TranscriptionResponseFormat = TranscriptionResponseFormat.JSON,
+                 file_duration: Optional[float] = None):
         assert file_uid is not None
         assert file_path is not None
         assert model is not None
@@ -35,13 +36,14 @@ class TranscriptionRequest:
         self.hotwords: Optional[List[str]] = None
         self.hotwords_weight: Optional[float] = None
         self.transcript_format: TranscriptionResponseFormat = transcript_format
+        self.file_duration: Optional[float] = file_duration
 
         if isinstance(hotwords, list):
             self.hotwords = hotwords
         elif isinstance(hotwords, str):
             self.hotwords = list(hotwords.split(','))
         elif hotwords is not None:
-            logger.warn(f'Couldn\'t parse hotwords: {hotwords}')
+            logger.warning(f'Couldn\'t parse hotwords: {hotwords}')
 
         try:
             if hotwords_weight is not None:
